# from tracardi.service.storage.collection_crud import CollectionCrud
#
#
# class Resources(list):
#
#     # Persistence
#     def bulk(self) -> CollectionCrud:
#         return CollectionCrud("resource", self)
